///////////////////////////////////////////////////////////////////////////////
//
//    (C) Copyright 2009-2010 OSR Open Systems Resources, Inc.
//    All Rights Reserved
//
//    This work is distributed under the OSR Non-Commercial Software License
//    which is provided at
//    "http://www.osronline.com/page.cfm?name=NonCommLicense" in
//    the hope that it will be enlightening, but WITHOUT ANY
//    WARRANTY; without even the implied warranty of
//    MECHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//
//            OSR Open Systems Resources, Inc.
//            105 Route 101A Suite 19
//            Amherst, NH 03031  (603) 595-6500 FAX: (603) 595-6503
//
//    MODULE:
//
//        help.cpp
//
//    ABSTRACT:
//
//       Help command(s)
//
//    AUTHOR(S):
//
//        OSR Open Systems Resources, Inc.
// 
//    REVISION:   
//
//
///////////////////////////////////////////////////////////////////////////////
#include "apexts.h"


///////////////////////////////////////////////////////////////////////////////
//
//  help
//
//    Extension command that prints help info
//
///////////////////////////////////////////////////////////////////////////////
HRESULT 
CALLBACK
help(
    PDEBUG_CLIENT4 Client, 
    PCSTR args
    ) {

    PDEBUG_CONTROL        debugControl;
    HRESULT               hr;

    UNREFERENCED_PARAMETER(args);

    // 
    // Our debug control instance will allow us to output.
    // 
    hr = Client->QueryInterface(__uuidof(IDebugControl),
                                (VOID **)&debugControl);

    if (hr != S_OK) {
        // 
        // Can't do anything but silently fail at this point...
        // 
        return hr;
    }

    CommandBanner(debugControl);

    debugControl->Output(DEBUG_OUTCTL_ALL_CLIENTS |
                         DEBUG_OUTCTL_OVERRIDE_MASK |
                         DEBUG_OUTCTL_NOT_LOGGED,
                         "\nAnalyst's Perspective Extensions:\n");
    debugControl->ControlledOutput(
                     DEBUG_OUTCTL_ALL_CLIENTS | DEBUG_OUTCTL_DML,
                     DEBUG_OUTPUT_NORMAL,
                     "\t<exec cmd=\"!uniqstack\">"\
                     "!uniqstack</exec> - Find unique threads in the system\n");

    debugControl->Output(DEBUG_OUTCTL_ALL_CLIENTS |
                         DEBUG_OUTCTL_OVERRIDE_MASK |
                         DEBUG_OUTCTL_NOT_LOGGED,
                         "\n");
    debugControl->Release();
    return S_OK;
}


///////////////////////////////////////////////////////////////////////////////
//
//  CommandBanner
//
//    Internal command to display a link to our site
//
///////////////////////////////////////////////////////////////////////////////
VOID
CommandBanner(
    PDEBUG_CONTROL DebugControl
    ) {

    // 
    // Print a DML tag that you can click to get to our site
    // 
    DebugControl->ControlledOutput(
                     DEBUG_OUTCTL_ALL_CLIENTS | DEBUG_OUTCTL_DML,
                     DEBUG_OUTPUT_NORMAL,
                     "This command brought to you by ");
    // 
    // There's a bug in the DML parser, so we need to do the command
    // as an alias.
    // 
    DebugControl->Execute(DEBUG_OUTCTL_ALL_CLIENTS |
                          DEBUG_OUTCTL_OVERRIDE_MASK |
                          DEBUG_OUTCTL_NOT_LOGGED,
                          "as LinkCmd .shell -ci \";\" "\
                          "start http://www.osronline.com", 
                          DEBUG_EXECUTE_DEFAULT);
    DebugControl->ControlledOutput(
                     DEBUG_OUTCTL_ALL_CLIENTS | DEBUG_OUTCTL_DML,
                     DEBUG_OUTPUT_NORMAL,
                     "<exec cmd=\"LinkCmd\">OSR Online</exec>\n");

    return;


}
